@@ -149,6 +149,8 @@ class ProgressController:
             Update scale on current changed
             @param player as Player
         """
+        if self._show_volume_control:
+            return
         self._progress.clear_marks()
         if player.current_track.id is None:
             self._progress.set_sensitive(False)
@@ -191,7 +193,10 @@ class ProgressController:
         """
         if self._show_volume_control:
             self._timelabel.set_text(_("Volume"))
+            # Inhibit _on_value_changed()
+            self._show_volume_control = False
             self._progress.set_range(0.0, 1.0)
+            self._show_volume_control = True
             self._progress.set_sensitive(True)
             self._update_position()
         else:
@@ -213,12 +218,25 @@ class ProgressController:
         Lp().player.set_volume(scale.get_value())
         self._update_position(scale.get_value())
 
+    def _on_title_press_button(self, widget, event):
+        """
+            Show/Hide volume control
+            @param widget as Gtk.Widget
+            @param event as Gdk.Event
+        """
+        if event.button != 1:
+            self.show_hide_volume_control()
+        return True
+
     def _on_progress_press_button(self, scale, event):
         """
             On press, mark player as seeking
             @param scale as Gtk.Scale
             @param event as Gdk.Event
         """
+        if event.button != 1:
+            self.show_hide_volume_control()
+            return True
         if self._show_volume_control:
             return
         if Lp().player.locked:
@@ -232,7 +250,7 @@ class ProgressController:
             @param scale as Gtk.Scale
             @param event as Gdk.Event
         """
-        if self._show_volume_control:
+        if self._show_volume_control or event.button != 1:
             return
         value = scale.get_value()
         Lp().player.seek(value/60)
