@@ -247,8 +247,8 @@ class Track(Base):
     """
     FIELDS = ['name', 'album_id', 'album_artist_ids',
               'artist_ids', 'genre_ids', 'album_name', 'artists', 'genres',
-              'duration', 'number', 'position', 'year', 'persistent', 'mtime']
-    DEFAULTS = ['', None, [], [], [], '', '', 0.0, None, 0, None, 1, 0]
+              'duration', 'number', 'year', 'persistent', 'mtime']
+    DEFAULTS = ['', None, [], [], [], '', '', '', 0.0, 0, None, 1, 0]
 
     def __init__(self, track_id=None):
         """
