@@ -35,24 +35,6 @@ class DeviceLocked(View):
         builder.get_object('label').set_text(_("Please unlock your device"))
 
 
-# FIXME Remove this later
-class DeviceMigration(View):
-    """
-        Show a message about old lollypop sync
-    """
-    def __init__(self):
-        """
-            Init view
-        """
-        View.__init__(self)
-        builder = Gtk.Builder()
-        builder.add_from_resource('/org/gnome/Lollypop/DeviceManagerView.ui')
-        self.add(builder.get_object('message'))
-        builder.get_object('label').set_text(
-            _("Lollypop sync changed due to limitations in some devices.\n"
-              "Please remove Music/lollypop folder on your device..."))
-
-
 class DeviceView(View):
     """
         Playlist synchronisation to MTP
